#!/usr/bin/perl -w

=head1 NAME

TheoryLearnerOrdered.pl 

=head1 SYNOPSIS

TheoryLearnerOrdered.pl LTBSpecFile filestem

=head1 CONTACT

Josef Urban (firstname dot lastname at gmail dot com)

=head1 COPYRIGHT

Copyright (C) 2012-2013 Josef Urban (firstname dot lastname at gmail dot com)

=head1 LICENCE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

=cut

$| = 1;


use strict;
use lib 'script';
use AITP_Data;
use AITP_ProblemIO;
use File::Spec;
use POSIX ':sys_wait_h';

my $MROOT = "/home/mptp/gr/MPTP2/MaLARea";
$MROOT = $ENV{"MLAR_ROOT"} if(exists($ENV{"MLAR_ROOT"}));
my $MBIN = "$MROOT/bin";
my $MSCRIPT = "$MROOT/script";
my $MTMP = "$MROOT/tmp";
my $MTMPAX = "$MROOT/tmp/Axioms";
my $MBLISTR = "$MROOT/blistr";
my $MBLISTRIN = "$MROOT/blistr/inputproblems";
my $MBLISTROUT = "$MROOT/blistr/inputproofs";
my $MBLISTRBIN = "$MROOT/blistr/bin";
my $MENIGMATIC = "$MROOT/enigmatic";


my @allargs = @ARGV;

my $ltbfile = shift @ARGV;
my $gfilestem = shift @ARGV;
my $goutputdir = shift(@ARGV);

die "At least three arguments required" 
    unless((defined($ltbfile) && defined($gfilestem) && defined($goutputdir)));

sub mywarn { print "% $$: ", @_; }

# sub dprint { } # print @_; }
sub dprint { print "% $$: ", @_; }

# used for exiting on SIGUSR1
sub childstopped 
{ 
    dprint "\nChild $$ stopped by parent\n";
    exit(0);
}

$SIG{USR1} = \&childstopped;

sub min { my ($x,$y) = @_; ($x <= $y)? $x : $y }
sub max { my ($x,$y) = @_; ($x <= $y)? $y : $x }


`mkdir -p $MTMPAX`;
`mkdir -p $MBLISTRIN`;
`mkdir -p $MBLISTRIN/all`;
`mkdir -p $MBLISTRIN/cnf`;
`mkdir -p $MBLISTROUT`;
`mkdir -p $MENIGMATIC`;

$ENV{PATH} = "$MBLISTRBIN:$ENV{PATH}";
$ENV{ENIGMA_ROOT} = "$MENIGMATIC/Enigma";
#export ENIGMA_ROOT="$PWD/Enigma"

#my %grefnr;                 # Ref2Nr hash for references
#my @gnrref;                 # Nr2Ref array for references
#my %grefsyms;     # Ref2Sym hash for each reference array of its symbols
#my %greftrmstd;   # Ref2Sym hash for each reference array of its stdterms (their shared-entry numbers)
#my %greftrmnrm;   # Ref2Sym hash for each reference array of its nrmterms (their share


# possible SZS statuses
sub szs_INIT        ()  { 'Initial' } # system was not run on the problem yet
sub szs_UNKNOWN     ()  { 'Unknown' } # used when system dies
sub szs_THEOREM     ()  { 'Theorem' }
sub szs_COUNTERSAT  ()  { 'CounterSatisfiable' }
sub szs_RESOUT      ()  { 'ResourceOut' }
sub szs_GAVEUP      ()  { 'GaveUp' }   # system exited before the time limit for unknown reason

# maximum lines in a file that we handle
my $gforgetlimit = 100000;# unless(defined($gforgetlimit));

my $gstarttime = time();

my ($gcategory, $gtraining_directory, $gbatches) = AITP_ProblemIO::ReadLTBData($ltbfile); 
# print "$ltbfile, $gcategory, $gtraining_directory\n"; 

# we need the problem names too for unordered
# my ($execution_order, $output_required, $problem_limit, $overall_limit, 
#	$include_files1, $ltbprobnames1, $ltbprobsolutions1) 
#	= @$batch;
my $gltbprobnames = $gbatches->[0]->[5];



my ($gminrefs, $gmincounts) = AITP_Data::DirProofSummary("$gtraining_directory/Solutions"); 

my $timeps = time();
dprint "\n% Time spent in proof summary:", $timeps - $gstarttime, "\n";


my ($gincludes) = AITP_Data::DirIncludeFiles("$gtraining_directory/Axioms");

my $timeincl = time();
dprint "\n% Time spent in includes:", $timeincl - $timeps, "\n";


# foreach $k (sort keys %$w) { print $k,":",join(",",@{$w->{$k}}),"\n"}

# prepare the training features and refs files, so we can run KNN on them
# we use the new fofshared (fofshared1) so we can update the hashtable
# (\%gref2fla, \%grefnr, \%gsymnr, \%gsymarity, \%grefsyms, \@gnrsym, \@gnrref, \%greftrmstd, \%greftrmnrm);
my ($gref2fla, $grefnr, $gsymnr, $gsymarity, $grefsyms, $gnrsym, $gnrref, $greftrmstd, 
    $greftrmnrm, $gcn_wght_std1,$gcn_wght_std2,$gcn_wght_nrm1,$gcn_wght_nrm2) =
    AITP_Data::PrepareTables($gtraining_directory,$gfilestem,$gltbprobnames);

my $timeprept = time();
dprint "\n% Time spent in preparing tables:", $timeps - $gstarttime, "\n";


my %gstdnr = ();
my %gnrmnr = ();

# the CASC24 ltb strategies:
# [featurekind, weighting, knn, slice, protokoll]
my @gLTBstrats =
(
["ful",0,0,0,"protokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12"],
["ful",0,0,0,"protocol_eprover_4a02c828a8cc55752123edbcc1ad40e453c11447"],
# ["ful",0,0,0,"protokoll_atpstr_my_c284f1f10aedfccc65cdb7d9b1210ef814cb8f1a"],
["std",1,128,128,"protokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7"],
["std",1,128,128,"protocol_eprover_f171197f65f27d1ba69648a20c844832c84a5dd7"],
["nrm",1,32,128,"protokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f"],
["nrm",1,32,128,"protocol_eprover_29fa5c60d0ee03ec4f64b055553dc135fbe4ee3a"],
["nrm",1,48,160,"protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["nrm",1,48,160,"protocol_eprover_773c90a94152ea2e8c9d3df9c4b1eb6152c40c03"],
["std",2,64,64,"protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["std",2,64,64,"protocol_eprover_2d86bd69119e7e9cc4417c0ee581499eaf828bb2"],
["nrm",2,256,256,"protokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219"],
["nrm",2,256,256,"protocol_eprover_230b6c199cce1dcf6700db59e75a93feb83d1bd9"],
["nrm",1,8,32,"protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["nrm",1,8,32,"protocol_eprover_63dc1b1eb7d762c2f3686774d32795976f981b97"],
["nrm",1,32,128,"protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["nrm",1,32,128,"protocol_eprover_f6eb5f7f05126ea361481ae651a4823314e3d740"],
["nrm",2,256,256,"protokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b"],
["nrm",1,128,72,"protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["nrm",1,48,20,"protokoll_atpstr_my_eba37f91665fc364eeb63558058658ee9a149d9a"],
["std",2,128,128,"protokoll_atpstr_my_8fb389ef013a89e03c1aa87be52b2f151b1819cc"],
["nrm",1,16,16,"protokoll_atpstr_my_fe548d15a6fc730fd350de634ad9d912ae198efd"],
["nrm",1,128,128,"protokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c"],
["nrm",2,512,512,"protokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c"],
["std",1,128,128,"protokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b"],
["std",2,128,128,"protokoll_atpstr_my_40306ce1a432dd48c918ac611d77fc5069b2fbc7"],
["nrm",1,32,32,"protokoll_atpstr_my_c13d4886baa4fa2cef7b4f50892895255b04b078"],
["nrm",1,128,72,"protokoll_atpstr_my_a4a4da5778ba9bebf9bc5e616786c7ad501b1af5"],
["nrm",1,32,32,"protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276"],
["nrm",1,16,64,"protokoll_atpstr_my_a473e2c35f909af4ba00d9f1a7a8a454a851ed9c"],
["nrm",2,512,512,"protokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219"],
["nrm",1,512,512,"protokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219"],
["nrm",1,64,90,"protokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12"],
["nrm",1,128,128,"protokoll_atpstr_my_2af8b399ea0b8c22c6fc1b13069ad80214f9fa8b"],
["nrm",1,128,128,"protokoll_atpstr_my_9fde028f05afb32f97bced19843d73b32d923682"],
["nrm",1,256,256,"protokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f"],
["nrm",2,512,512,"protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276"],
["nrm",2,256,256,"protokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12"],
["nrm",1,48,160,"protokoll_atpstr_my_eba37f91665fc364eeb63558058658ee9a149d9a"],
["nrm",1,64,64,"protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["nrm",1,32,32,"protokoll_atpstr_my_2af8b399ea0b8c22c6fc1b13069ad80214f9fa8b"],
["nrm",1,64,64,"protokoll_atpstr_my_edc94794a7d25c504761344c2a8b4afaac43a2d0"],
["std",2,48,48,"protokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7"],
["nrm",1,32,128,"protokoll_atpstr_my_1518b94b1627f7a5f7ce55e37817c09306fe714c"],
["nrm",1,48,440,"protokoll_atpstr_my_c13d4886baa4fa2cef7b4f50892895255b04b078"],
["nrm",1,128,128,"protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["std",1,48,48,"protokoll_atpstr_my_a473e2c35f909af4ba00d9f1a7a8a454a851ed9c"],
["std",2,128,128,"protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276"],
["nrm",2,64,64,"protokoll_atpstr_my_c284f1f10aedfccc65cdb7d9b1210ef814cb8f1a"]
);


my @gLTBstratsIter2Enigma =
(
["ful",0,0,0,"ECprotokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12"],
["ful",0,0,0,"ECprotocol_eprover_4a02c828a8cc55752123edbcc1ad40e453c11447"],
["std",1,128,128,"ECprotokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7"],
["std",1,128,128,"ECprotocol_eprover_f171197f65f27d1ba69648a20c844832c84a5dd7"],
["nrm",1,32,128,"ECprotokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f"],
["nrm",1,32,128,"ECprotocol_eprover_29fa5c60d0ee03ec4f64b055553dc135fbe4ee3a"],
["nrm",1,48,160,"ECprotokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["nrm",1,48,160,"ECprotocol_eprover_773c90a94152ea2e8c9d3df9c4b1eb6152c40c03"],

["std",2,64,64,"ECprotokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["std",2,64,64,"ECprotocol_eprover_2d86bd69119e7e9cc4417c0ee581499eaf828bb2"],
["nrm",2,256,256,"ECprotokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219"],
["nrm",2,256,256,"ECprotocol_eprover_230b6c199cce1dcf6700db59e75a93feb83d1bd9"],
["nrm",1,8,32,"ECprotokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["nrm",1,8,32,"ECprotocol_eprover_63dc1b1eb7d762c2f3686774d32795976f981b97"],
["nrm",1,32,128,"ECprotokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["nrm",1,32,128,"ECprotocol_eprover_f6eb5f7f05126ea361481ae651a4823314e3d740"],

["nrm",2,256,256,"ECprotokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b"],
["nrm",1,128,72,"ECprotokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["nrm",1,48,20,"ECprotokoll_atpstr_my_eba37f91665fc364eeb63558058658ee9a149d9a"],
["std",2,128,128,"ECprotokoll_atpstr_my_8fb389ef013a89e03c1aa87be52b2f151b1819cc"],
["nrm",1,16,16,"ECprotokoll_atpstr_my_fe548d15a6fc730fd350de634ad9d912ae198efd"],
["nrm",1,128,128,"ECprotokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c"],
["nrm",2,512,512,"ECprotokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c"],
["std",1,128,128,"ECprotokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b"]
);



# these are shifted down by 2 from normal ltb strats, plus the first
# and second ful are the same as the 5th and 6th
my @gLTBstratsIter2 =
(
["ful",0,0,0,      "protocol_eprover_4a02c828a8cc55752123edbcc1ad40e453c11447"],
["ful",0,0,0,      "protocol_eprover_2d86bd69119e7e9cc4417c0ee581499eaf828bb2"],
["std",1,128,128,  "protocol_eprover_4a02c828a8cc55752123edbcc1ad40e453c11447"],
["std",1,128,128,  "protocol_eprover_2d86bd69119e7e9cc4417c0ee581499eaf828bb2"],
["nrm",1,32,128,   "protocol_eprover_29fa5c60d0ee03ec4f64b055553dc135fbe4ee3a"],
["nrm",1,32,128,   "protocol_eprover_63dc1b1eb7d762c2f3686774d32795976f981b97"],
["nrm",1,48,160,   "protocol_eprover_f171197f65f27d1ba69648a20c844832c84a5dd7"],
["nrm",1,48,160,   "protocol_eprover_230b6c199cce1dcf6700db59e75a93feb83d1bd9"],
["std",2,64,64,    "protocol_eprover_773c90a94152ea2e8c9d3df9c4b1eb6152c40c03"],
["std",2,64,64,    "protocol_eprover_f6eb5f7f05126ea361481ae651a4823314e3d740"],
["nrm",2,256,256,  "protocol_eprover_eb48853eb71ccd2a6fdade56c25b63f5692e1a0c"],
["nrm",2,256,256,  "protocol_eprover_75515770aeb32f68e33e9fbd9dff93f5a2e34f2e"],
["nrm",1,8,32,     "protocol_eprover_48e494e00e0717ec2eabf59b73b2d711334607de"],
["nrm",1,8,32,     "protocol_eprover_a172c605141d0894bf6fdc293a5220c6c2a32117"],
["nrm",1,32,128,   "protocol_eprover_761a0d093d9701c0eed884aebb46468e8d439c31"],
["nrm",1,32,128,   "protocol_eprover_6c565d2524e660970ec2a72c26d577f665a55420"],
["nrm",2,256,256,  "protocol_eprover_33aa8a325940064c53b389b41203bb48a5cb5006"],
["nrm",1,128,72,   "protocol_eprover_f8b0f932169414d689b89e2a8b18d4600533b975"],
["nrm",1,48,20,    "protocol_eprover_bb5e3cecdbc7660bd3a6f864cadb7769d8aea26a"],
["std",2,128,128,  "protocol_eprover_750456fc664a9e0b97096ad0f5110b1ead7d782b"],
["nrm",1,16,16,    "protocol_eprover_260890dcdd2d907655d788d68835201aeffdef4a"],
["nrm",1,128,128,  "protocol_eprover_fc511518e5f98a6b2c7baef820b71b6d1abb3e55"],
["nrm",2,512,512,  "protocol_eprover_e252f7803940d118fa0ef69fc2319cb55aee23b9"],
["std",1,128,128,  "protocol_eprover_a9abcacdf80c460fdc9fe242616d68da2308faf5"],
["std",2,128,128,  "protocol_eprover_9a428cb4e1feff5dec19b8494e78e7f0e8ede446"],
["nrm",1,32,32,    "protocol_eprover_95b56b3f38545d2cfee43b45856d192a814b65d5"],
["nrm",1,128,72,   "protocol_eprover_b1d72019af42f5b571a6c0b233a5b6d1de064075"],
["nrm",1,32,32,    "protocol_eprover_e60008599937a0dc787316fd87bf9ff4d65ffb48"],
["nrm",1,16,64,    "protocol_eprover_e6b386026570787d4ac06e541c4634c5e3f09cc5"],
["nrm",2,512,512,  "protocol_eprover_6017f334107ca4679a9978dd19d7c76a8bd36e48"],
["nrm",1,512,512,  "protocol_eprover_e96ef4641ae500918cdd95fcfce21e29f2ac5eec"],
["nrm",1,64,90,    "protocol_eprover_03d534503f753dd3be02bb3c547fa7a3e34e825e"],
["nrm",1,128,128,  "protocol_eprover_2e85aeff02a0bd3743f362014f6604d7fba54d74"],
["nrm",1,128,128,  "protocol_eprover_29f46a864b4eba32a7d0333eeab34cc2a3bfeeb2"],
["nrm",1,256,256,  "protocol_eprover_1f734394cb6ce69b36c9826f6782d3567d6ecd6c"],
["nrm",2,512,512,  "protocol_eprover_f8481b8ca6e1cbe7ac35251a2832c4c110836158"],
["nrm",2,256,256,  "protocol_eprover_334d43c175335e554899225728a5c2ebd420f86b"],
["nrm",1,48,160,   "protocol_eprover_6c6e328223588bd61ac14315e52cd57432d78a40"],
["nrm",1,64,64,    "protocol_eprover_e9eb28a402764e1f99b41605245cd0a359f475fb"],
["nrm",1,32,32,    "protocol_eprover_4692c23f3ccd5aecc2adbd7957ddb4b4144a02c8"],
["nrm",1,64,64,    "protocol_eprover_13918ce26d63c8fe682016bfda2032977bcbf85b"],
["std",2,48,48,    "protocol_eprover_d060f57557112503de4e70311f17201fbe20b6a3"],
["nrm",1,32,128,   "protocol_eprover_3dd3316ad6e39f95bf120b2757347c6970e0a532"],
["nrm",1,48,440,   "protocol_eprover_b44ef8977635a59c8900801cfd301da75891626e"],
["nrm",1,128,128,  "protocol_eprover_374255c1532cc4daa30b60038971be8183a2c553"],
["std",1,48,48,    "protocol_eprover_7e73d521eed2eff17dc17155adefb3ab5d9c1092"],
["std",2,128,128,      "protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],		
["nrm",2,64,64,      "protokoll_atpstr_my_a473e2c35f909af4ba00d9f1a7a8a454a851ed9c"]		
);
#		       "protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276"],		
#		     "protokoll_atpstr_my_c284f1f10aedfccc65cdb7d9b1210ef814cb8f1a"]            


# TODO: put this in a separate file
# strategy defs
my %sdef =
(
'protokoll_G-E--_008_K18_F1_PI_AE_CS_SP_S0Y' => '  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'protokoll_G-E--_045_K18_F1_PI_AE_CS_OS_S0S_sine05' => '  --sine=gf120_gu_RUU_F100_L00100 --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(4*Refinedweight(SimulateSOS,1,1,2,1.5,2),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_107_C37_F1_PI_AE_Q4_CS_SP_PS_S0Y' => '  --definitional-cnf=24 --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --presat-simplify --prefer-initial-clauses -tKBO6 -warity -c1 -Ginvconjfreq -F1  --delete-bad-limit=1024000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*RelevanceLevelWeight2(SimulateSOS,0,2,1,2,100,100,100,400,1.5,1.5,1),3*ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,50,50,1,100,1.5,1.5,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\'  ',
'protokoll_X----_auto_sine03' => '  --delete-bad-limit=1024000000 -xAuto -tAuto --sine=gf120_gu_R02_F100_L20000 ',
'protokoll_X----_auto_sine05' => '  --delete-bad-limit=1024000000 -xAuto -tAuto --sine=gf120_gu_RUU_F100_L00100 ',
'protokoll_X----_auto_sine13' => '   --delete-bad-limit=1024000000 -xAuto -tAuto --sine=gf120_h_gu_R02_F100_L20000 ',
'protokoll_X----_sauto_300' => '   --delete-bad-limit=1024000000 --auto ',
'protokoll_my10simple' => '  --definitional-cnf=24 --split-clauses=7 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed),1*FIFOWeight(ConstPrio))\'  ',
'protokoll_my11simple' => '  --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(PreferProcessed),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Refinedweight(SimulateSOS,1,1,2,1.5,2),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ',
'protokoll_my11simple_sine13' => '  --sine=gf120_h_gu_R02_F100_L20000 --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(PreferProcessed),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Refinedweight(SimulateSOS,1,1,2,1.5,2),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ',
'protokoll_my12simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my13simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),8*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my14simple' => '  --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(ConstPrio))\'  ',
'protokoll_my15simple' => '  --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP -H\'(1*Refinedweight(SimulateSOS,1,1,2,1.5,2),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my16simple' => '  --definitional-cnf=24 --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ',
'protokoll_my17simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100,1.5, 1.5, 1),10*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ',
'protokoll_my17simple_sine13' => '  --sine=gf120_h_gu_R02_F100_L20000 --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100,1.5, 1.5, 1),10*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ',
'protokoll_my18simple' => '  --definitional-cnf=24  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP -H\'(1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my19simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),10*Refinedweight(SimulateSOS,1,1,2,1.5,2),2*FIFOWeight(PreferProcessed),8*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'protokoll_my1KBO_SOS' => '  --definitional-cnf=24  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*Refinedweight(SimulateSOS,1,1,2,1.5,2),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my1_SOS' => '  --definitional-cnf=24  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*Refinedweight(SimulateSOS,1,1,2,1.5,2),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my20simple' => '  --definitional-cnf=24  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*Refinedweight(SimulateSOS,1,1,2,1.5,2),1*FIFOWeight(ConstPrio),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my21simple' => '  --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my22simple' => '  --definitional-cnf=24  --split-clauses=7 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(ConstPrio),6*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ',
'protokoll_my23simple' => '  --definitional-cnf=24  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(PreferProcessed),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ',
'protokoll_my24simple' => '  --definitional-cnf=24  --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),8*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ',
'protokoll_my25simple' => '  --definitional-cnf=24  --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed),1*FIFOWeight(ConstPrio))\'  ',
'protokoll_my2simple' => ' --definitional-cnf=24  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my3simple' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my4simple' => ' --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1))\'  ',
'protokoll_my5simple' => '  --definitional-cnf=24  --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my6simple' => '  --definitional-cnf=24  --split-clauses=7 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my7simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(PreferProcessed),1*FIFOWeight(ConstPrio),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my8simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my8simple_sine13' => '  --sine=gf120_h_gu_R02_F100_L20000 --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my9simple' => '  --definitional-cnf=24 --split-aggressive --split-clauses=7 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(ConstPrio),2*Refinedweight(SimulateSOS,1,1,2,1.5,2),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*FIFOWeight(PreferProcessed),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1))\' ',
'protokoll_G-E--_008_B31_F1_PI_AE_S4_CS_SP_S2S' => '  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'protokoll_G-E--_010_B02_F1_PI_AE_S4_CS_SP_S0Y' => '  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_045_B31_F1_PI_AE_S4_CS_SP_S0Y' => '  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*Refinedweight(SimulateSOS,1,1,2,1.5,2),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_024_B07_F1_PI_AE_Q4_CS_SP_S0Y' => '  --split-reuse-defs --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*ConjectureGeneralSymbolWeight(SimulateSOS,100,100,100,50,50,50,50,1.5,1.5,1),3*ConjectureGeneralSymbolWeight(PreferNonGoals,100,100,100,50,50,1000,100,1.5,1.5,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_045_K18_F1_PI_AE_CS_OS_S0S' => '  --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(4*Refinedweight(SimulateSOS,1,1,2,1.5,2),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_107_C37_F1_PI_AE_Q4_CS_SP_PS_S0Y_sine13' => '  --sine=gf120_h_gu_R02_F100_L20000 --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --presat-simplify --prefer-initial-clauses -tKBO6 -warity -c1 -Ginvconjfreq -F1 -s --delete-bad-limit=1024000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*RelevanceLevelWeight2(SimulateSOS,0,2,1,2,100,100,100,400,1.5,1.5,1),3*ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,50,50,1,100,1.5,1.5,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ', 
'protokoll_G-E--_052_K18_F1_PI_AE_Q4_CS_SP_S0Y' => '  --split-reuse-defs --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.05, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(SimulateSOS))\' ',
'protokoll_G-E--_092_C01_F1_PI_AE_Q4_CS_SP_PS_S0Y' => '  --definitional-cnf=24 --tstp-in --presat-simplify --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 -s --delete-bad-limit=1024000000 -WSelectMaxLComplexAvoidPosPred -tKBO6 -H\'(4*RelevanceLevelWeight2(SimulateSOS,1,2,0,2,100,100,100,400,1.5,1.5,1),3*ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,50,50,1,100,1.5,1.5,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_008_C18_F1_PI_AE_Q4_CS_SP_PS_S0Y' => '  --definitional-cnf=24 --split-reuse-defs --split-clauses=4 --tstp-in --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er  --presat-simplify --prefer-initial-clauses -tKBO6 -winvfreqrank -c1 -Ginvfreq -F1 -s --delete-bad-limit=1024000000 -WSelectMaxLComplexAvoidPosPred -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'protokoll_G-E--_008_B07_F1_PI_AE_Q4_CS_SP_S2S' => '  --split-reuse-defs --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',


# the tstf6_40_128 prots
'protokoll_atpstr_my_05c900b7acd7e0314c15fce53bb9e79cf904cd89' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.5,, 03, 40,1.0)\' --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-clauses=4 -tLPO4 -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),4*Clauseweight(ConstPrio,3,1,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'   ' ,
'protokoll_atpstr_my_0b08a1d1a32ffc279e90769114bdfda18e672e1c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 03, 40,1.0)\' -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-aggressive --split-reuse-defs -tAuto -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),4*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),12*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed))\'  ' ,
'protokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 02, 100,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tKBO -H\'(4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\'  ' ,
'protokoll_atpstr_my_3e6c84c618b85cc326775b240e7b2b07e3a2dde9' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Ginvfreqconstmin -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-clauses=4 -tAuto -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(ConstPrio,3,1,1),1*FIFOWeight(ConstPrio))\'  ' ,
'protokoll_atpstr_my_4e6e6157a8ac18b9bae11142d40377c9660db06b' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 6.0,, 02, 100,1.0)\' --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),2*Clauseweight(ConstPrio,3,1,1),2*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),10*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ' ,
'protokoll_atpstr_my_5fce846ef89413a220d0951fb615d42ded72b119' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(ConstPrio,3,1,1),1*FIFOWeight(PreferProcessed),8*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ' ,
'protokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 5.0,, 02, 80,1.0)\' -Garity -WSelectNewComplexAHP --simul-paramod -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ConstPrio,3,1,1),2*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ' ,
'protokoll_atpstr_my_92168ebc2ef464a6f2d6a311a4fa90219fd0aa91' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 6.0,, 02, 20000,1.0)\' --forward-context-sr -Garity -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-reuse-defs -tAuto -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),12*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),8*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ' ,
'protokoll_atpstr_my_a175515211bb22b22434eae9bbbfab623676a2ba' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectComplexG --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ' ,
'protokoll_atpstr_my_a473e2c35f909af4ba00d9f1a7a8a454a851ed9c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.4,, , 20,1.0)\' -Ginvfreqconstmin -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-aggressive --split-clauses=4 -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(PreferProcessed))\'  ' ,
'protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 6.0,, 01, 80,1.0)\' -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ' ,
'protokoll_atpstr_my_c284f1f10aedfccc65cdb7d9b1210ef814cb8f1a' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 5.0,, 02, 60,1.0)\' --forward-context-sr -Garity -WSelectComplexG --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ' ,
'protokoll_atpstr_my_e4d2b8713a71da3a6bc64790217310975ccdde24' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 01, 20000,1.0)\' -winvfreqrank -c1 -Ginvfreq -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tLPO4 -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(PreferProcessed),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\' ' ,
'protokoll_atpstr_my_e8ac4ce30401bd9e99200725cfa03816a32e3aa4' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 5.0,, 01, 20000,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-aggressive -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),12*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\' ', 

# m10u2_184
'protokoll_atpstr_my_1518b94b1627f7a5f7ce55e37817c09306fe714c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.2,, 02, 40,1.0)\' -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod -tAuto -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),8*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(ByCreationDate,2,1,0.8),2*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'protokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Garity -WSelectComplexG --simul-paramod -tAuto -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\'  ', 
'protokoll_atpstr_my_304d2e324da665c057353a60ddd91c0712280c88' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.1,, 02, 60,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),4*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'protokoll_atpstr_my_69856783cec8fab1acccfe08bb382ad42c8475df' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 6.0,, , 100,1.0)\' -Garity -WSelectComplexG --simul-paramod --split-clauses=7 -tKBO -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'protokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 02, 100,1.0)\' --forward-context-sr -Garity -WSelectComplexG --simul-paramod --split-clauses=7 -tKBO -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'protokoll_atpstr_my_8fb389ef013a89e03c1aa87be52b2f151b1819cc' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.1,, 04, 80,1.0)\' -Garity -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-clauses=4 --split-reuse-defs -tAuto -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'protokoll_atpstr_my_a3154f3180cc47331f1b05c36960c32e4805a7c5' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 6.0,, 01, 20000,1.0)\' --forward-context-sr -Garity -WSelectComplexG --simul-paramod --split-clauses=4 -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'protokoll_atpstr_my_a4a4da5778ba9bebf9bc5e616786c7ad501b1af5' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 03, 20,1.0)\' --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-aggressive --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'protokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.5,, 04, 100,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),4*Clauseweight(ConstPrio,3,1,1),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ', 
'protokoll_atpstr_my_e3b5200232138aedc93b8882335da60ccd317d87' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.2,, 01, 80,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(PreferProcessed,1,1,1))\'  ', 
'protokoll_atpstr_my_e6869afe09f22abfbe1163ee95524cfdbfe77603' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 04, 40,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 -tLPO4 -H\'(2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(ConstPrio,3,1,1),2*FIFOWeight(PreferProcessed),10*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ', 
'protokoll_atpstr_my_e6ff24ca1a5013a612ccffc94da0b282477718de' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.5,, 02, 100,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod -tKBO -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\'  ', 
'protokoll_atpstr_my_eba37f91665fc364eeb63558058658ee9a149d9a' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 02, 60,1.0)\' --forward-context-sr -Garity -WSelectNewComplexAHP --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),2*Clauseweight(ConstPrio,3,1,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),8*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'protokoll_atpstr_my_fc3fb6907f504dffe1a6181663296b37fe358480' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 -Ginvfreqconstmin -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\' ',

# new_mzt_small
'protokoll_atpstr_my_2af8b399ea0b8c22c6fc1b13069ad80214f9fa8b' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 5.0,, 6, 80,1.0)\' -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-reuse-defs -tKBO -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*FIFOWeight(PreferProcessed),10*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.5,, 2, 60,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --oriented-simul-paramod --split-aggressive --split-reuse-defs -tLPO4 -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),8*Clauseweight(ConstPrio,3,1,1),2*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),10*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_40306ce1a432dd48c918ac611d77fc5069b2fbc7' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Garity -WSelectComplexG --simul-paramod -tKBO -H\'(2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(ConstPrio),4*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_43029cedefea4858aae9c4ebd6be482056ce22f4' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod -tKBO -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_9cb7c8ca63fd56afb053ade56353a3b00eee7e6a' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.2,, 4, 100,1.0)\' --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed))\' ',
'protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 2.0,, 3, 20,1.0)\' -Garity -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tKBO -H\'(4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(ConstPrio),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),10*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_9fde028f05afb32f97bced19843d73b32d923682' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --oriented-simul-paramod --split-aggressive -tKBO -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_c0d9db6a7b7a90437bd07739f25aa91c0ffc1607' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=4 -tKBO -H\'(10*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\' ',
'protokoll_atpstr_my_c13d4886baa4fa2cef7b4f50892895255b04b078' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 1, 80,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod -tKBO -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 -Garity -WSelectComplexG --simul-paramod -tLPO4 -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_atpstr_my_edc94794a7d25c504761344c2a8b4afaac43a2d0' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 5.0,, , 100,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 --split-reuse-defs -tKBO -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\' ',
'protokoll_atpstr_my_f67d73f57ffeda22ddd93400237cd848911520e5' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 -Garity -WSelectComplexG --simul-paramod --split-aggressive --split-clauses=4 -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_atpstr_my_f9ecf400d7420b0148b2ef7cf4b1498512cf83fd' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\' ',
'protokoll_atpstr_my_fe548d15a6fc730fd350de634ad9d912ae198efd' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --simul-paramod --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',


# honza SLH
'protocol_eprover_4a02c828a8cc55752123edbcc1ad40e453c11447' => ' --definitional-cnf=24   --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.4,,04,100,1.0)\' -H\'(1*Clauseweight(PreferUnitGroundGoals,4,9999,5),1*PNRefinedweight(PreferNonGoals,300,3,4,20,4,0.2,0.2),2*ConjectureLevDistanceWeight(ConstPrio,1,0,50,20,7,0,0.8,1.5,2),2*StaggeredWeight(PreferGroundGoals,1.5),4*ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,10,100,100,4,1.5,1))\' ',
'protocol_eprover_f171197f65f27d1ba69648a20c844832c84a5dd7' => ' --definitional-cnf=24    --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO6 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*ConjectureSymbolWeight(ConstPrio,9999,5,10,50,50,4,3,0.5),1*ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,9999.9,3,5),1*FIFOWeight(PreferProcessed),3*ConjectureRelativeSymbolWeight(ConstPrio,0.7,100,100,100,100,2,1.5,1.5),5*Clauseweight(PreferUnitGroundGoals,7,9999,5))\' ',
'protocol_eprover_29fa5c60d0ee03ec4f64b055553dc135fbe4ee3a' => ' --definitional-cnf=24  --split-clauses=7 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*StaggeredWeight(DeferSOS,1),2*ConjectureGeneralSymbolWeight(PreferNonGoals,5,100,300,4,-2,7,50,5,1,0.7),2*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,0,400,5,3,3,1),2*StaggeredWeight(DeferSOS,2),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.3,1.5,1.5))\' ',
'protocol_eprover_773c90a94152ea2e8c9d3df9c4b1eb6152c40c03' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4 --split-reuse-defs --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.5,,,100,1.0)\' -H\'(1*Clauseweight(PreferGoals,20,9999,3),1*ConjectureTermPrefixWeight(ConstPrio,1,3,5,9999.9,2,5,5,5),1*FIFOWeight(PreferProcessed),2*ConjectureLevDistanceWeight(PreferNonGoals,1,0,20,300,4,0,2.5,0.8,3),4*ConjectureGeneralSymbolWeight(ConstPrio,4,10,200,3,-2,1,50,0.7,4,2))\' ',
'protocol_eprover_2d86bd69119e7e9cc4417c0ee581499eaf828bb2' => ' --definitional-cnf=24  --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG --sine=\'GSinE(CountFormulas,,1.1,,02,500,1.0)\' -H\'(2*StaggeredWeight(DeferSOS,1.5),2*Uniqweight(PreferProcessed),4*ClauseWeightAge(ConstPrio,1,100,2.5,0.7),8*ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,3,4,9999,0,0,0,7,0.1,5,1.5))\' ',
'protocol_eprover_230b6c199cce1dcf6700db59e75a93feb83d1bd9' => ' --definitional-cnf=24  --split-clauses=4  --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.1,,01,20000,1.0)\' -H\'(1*Clauseweight(PreferNonGoals,20,300,1.5),10*ConjectureGeneralSymbolWeight(PreferProcessed,100,9999,9999,4,-2,3,5,4,0.2,5),13*ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,100,400,-2,18,0,3,50,2.5,0.2,4),2*ConjectureRelativeSymbolWeight(PreferGroundGoals,2,7,-2,300,200,9999.9,2,2),3*FIFOWeight(PreferProcessed))\' ',
'protocol_eprover_63dc1b1eb7d762c2f3686774d32795976f981b97' => ' --definitional-cnf=24    --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO6 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*ConjectureSymbolWeight(ConstPrio,9999,18,4,18,50,0.7,3,0.8),1*ConjectureTermPrefixWeight(ByCreationDate,1,3,1,9999.9,0,9999.9,3,5),1*FIFOWeight(PreferProcessed),3*ConjectureRelativeSymbolWeight(ConstPrio,0.7,100,100,100,100,2,1.5,1.5),5*Clauseweight(PreferProcessed,1,9999,5))\' ',
'protocol_eprover_f6eb5f7f05126ea361481ae651a4823314e3d740' => ' --definitional-cnf=24  --split-clauses=4  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.5,,02,20000,1.0)\' -H\'(3*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,50,18,7,20,1,1.5,4),34*ConjectureLevDistanceWeight(PreferNonGoals,1,0,10,10,10,0,1,0.5,3))\' ',
'protocol_eprover_eb48853eb71ccd2a6fdade56c25b63f5692e1a0c' => ' --definitional-cnf=24  --split-clauses=7 --split-reuse-defs  --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*Clauseweight(PreferProcessed,20,300,3),2*ClauseWeightAge(SimulateSOS,-1,200,0.5,0.1),5*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,2,1,3,1),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,-2,100,100,1.5,1.5,1.5),8*FIFOWeight(PreferProcessed))\' ',
'protocol_eprover_75515770aeb32f68e33e9fbd9dff93f5a2e34f2e' => ' --definitional-cnf=24 --split-aggressive   --simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(2*ConjectureTermPrefixWeight(DeferSOS,1,3,5,100,0,2,0.3,5),21*ConjectureSymbolWeight(ConstPrio,200,300,7,20,3,0.3,0.3,0.7),3*ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,100,2,2.5,3,1),5*ConjectureSymbolWeight(ConstPrio,9999,50,-1,7,50,0.8,3,0.7))\' ',
'protocol_eprover_48e494e00e0717ec2eabf59b73b2d711334607de' => ' --definitional-cnf=24 --split-aggressive    --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.1,,03,20000,1.0)\' -H\'(3*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,-1,100,400,2,1,3,0.8),3*FIFOWeight(PreferProcessed),34*ConjectureGeneralSymbolWeight(PreferProcessed,100,300,50,4,-2,-2,50,3,0.2,4),4*ConjectureTermPrefixWeight(PreferNonGoals,1,3,0.5,9999.9,0,4,3,5),8*Clauseweight(PreferProcessed,20,300,3),8*PNRefinedweight(PreferUnitGroundGoals,5,-1,9999,3,2,3,0.5))\' ',
'protocol_eprover_a172c605141d0894bf6fdc293a5220c6c2a32117' => ' --definitional-cnf=24   --split-reuse-defs --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG  -H\'(1*FIFOWeight(PreferProcessed),1*RelevanceLevelWeight2(SimulateSOS,0,1,1,0,400,200,18,50,1,5,4),1*StaggeredWeight(PreferGroundGoals,1.5),3*FIFOWeight(PreferProcessed),8*ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,9999,400,5,4,0.8))\' ',
'protocol_eprover_761a0d093d9701c0eed884aebb46468e8d439c31' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.2,,,100,1.0)\' -H\'(1*OrientLMaxWeight(PreferUnitGroundGoals,1,18,1,0.2,4),2*ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,9999.9,0,1,0.8,5),4*ConjectureRelativeSymbolWeight(PreferNonGoals,1,100,4,100,100,2.5,0.7,0.8),4*FIFOWeight(PreferProcessed),8*RelevanceLevelWeight(DeferSOS,1,1,0,0,3,5,9999,50,4,4,0.5))\' ',
'protocol_eprover_6c565d2524e660970ec2a72c26d577f665a55420' => ' --definitional-cnf=24  --split-clauses=7 --split-reuse-defs  --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*Defaultweight(PreferGroundGoals),2*Clauseweight(PreferProcessed,4,300,3),4*ConjectureTermTfIdfWeight(PreferProcessed,1,1,1,10,2,5,0.7,0.8),6*Clauseweight(SimulateSOS,18,9999,4),8*FIFOWeight(PreferNonGoals))\' ',
'protocol_eprover_33aa8a325940064c53b389b41203bb48a5cb5006' => ' --definitional-cnf=24  --split-clauses=4 --split-reuse-defs --simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectCQPrecWNTNp  -H\'(1*ConjectureSymbolWeight(ConstPrio,9999,200,10,400,100,2,3,0.5),1*Refinedweight(PreferUnitGroundGoals,20,100,0.3,0.2,0.2),34*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.5,1,1.5))\' ',
'protocol_eprover_f8b0f932169414d689b89e2a8b18d4600533b975' => ' --definitional-cnf=24  --split-clauses=4  --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO6 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*FIFOWeight(PreferNonGoals),10*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,100,3,1.5,1.5),3*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,2.5,1,0.7))\' ',
'protocol_eprover_bb5e3cecdbc7660bd3a6f864cadb7769d8aea26a' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4 --split-reuse-defs --oriented-simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO6 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG --sine=\'GSinE(CountFormulas,hypos,1.1,,,500,1.0)\' -H\'(1*ConjectureGeneralSymbolWeight(ConstPrio,3,2,7,1,-2,-2,3,0.2,0.5,0.2),2*ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,7,300,300,0,-2,200,20,4,0.3,0.2),3*ConjectureRelativeSymbolWeight(ConstPrio,0.1,3,5,20,1,0.8,0.2,0.2))\' ',
'protocol_eprover_750456fc664a9e0b97096ad0f5110b1ead7d782b' => ' --definitional-cnf=24  --split-clauses=4 --split-reuse-defs  --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO6 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*ConjectureTermPrefixWeight(ByCreationDate,1,3,10,9999.9,0,0.1,1.5,3),10*RelevanceLevelWeight2(ConstPrio,0,2,1,0,100,100,100,400,0.7,4,0.3),3*ConjectureGeneralSymbolWeight(ConstPrio,200,50,200,18,1,2,50,0.1,4,5),4*StaggeredWeight(PreferNonGoals,2))\' ',
'protocol_eprover_260890dcdd2d907655d788d68835201aeffdef4a' => ' --definitional-cnf=24  --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,,1.5,,03,100,1.0)\' -H\'(1*Clauseweight(PreferUnitGroundGoals,300,7,4),1*ConjectureTermPrefixWeight(ByCreationDate,1,3,0,0.5,1,4,1,4),1*StaggeredWeight(PreferGroundGoals,2),2*ConjectureLevDistanceWeight(PreferUnitGroundGoals,1,0,5,400,4,0,2.5,0.8,3),4*ConjectureGeneralSymbolWeight(PreferGroundGoals,-2,4,100,3,-2,20,50,1,4,1))\' ',
'protocol_eprover_fc511518e5f98a6b2c7baef820b71b6d1abb3e55' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4    --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.4,,02,80,1.0)\' -H\'(1*ConjectureSymbolWeight(ConstPrio,9999,100,3,20,300,0.2,3,1.5),13*FIFOWeight(PreferProcessed),21*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,20,300,9999,-2,5,0.8,1),4*ConjectureTermTfIdfWeight(SimulateSOS,0,0,0,9999.9,1,0.8,9999.9,0.1),5*FIFOWeight(DeferSOS),5*FIFOWeight(PreferNonGoals))\' ',
'protocol_eprover_e252f7803940d118fa0ef69fc2319cb55aee23b9' => ' --definitional-cnf=24 --split-aggressive  --split-reuse-defs --oriented-simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,,1.4,,03,100,1.0)\' -H\'(1*SymbolTypeweight(SimulateSOS,20,1,18,-2,9999.9,2,1.5),4*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,2,100,100,3,1.5,0.8),5*ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,3,1,10,2,9999.9,5,0.5))\' ',
'protocol_eprover_a9abcacdf80c460fdc9fe242616d68da2308faf5' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4 --split-reuse-defs --oriented-simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG --sine=\'GSinE(CountFormulas,hypos,1.1,,02,500,1.0)\' -H\'(2*StaggeredWeight(PreferNonGoals,1),3*ConjectureGeneralSymbolWeight(DeferSOS,18,9999,9999,-1,0,20,200,0.2,0.2,2),34*ConjectureGeneralSymbolWeight(PreferGroundGoals,7,200,9999,5,0,-2,4,0.3,2,2.5),4*StaggeredWeight(PreferUnitGroundGoals,1.5))\' ',
'protocol_eprover_9a428cb4e1feff5dec19b8494e78e7f0e8ede446' => ' --definitional-cnf=24 --split-aggressive  --split-reuse-defs --simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP  -H\'(3*ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,2,1,1),4*SymbolTypeweight(PreferProcessed,10,1,-1,4,0.5,2,1),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,3,200,100,5,1.5,1.5))\' ',
'protocol_eprover_95b56b3f38545d2cfee43b45856d192a814b65d5' => ' --definitional-cnf=24  --split-clauses=4 --split-reuse-defs --oriented-simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(2*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,200,-2,0.2,1,0.8),2*ConjectureSymbolWeight(ConstPrio,400,400,18,200,4,2,3,0.7),2*ConjectureSymbolWeight(ConstPrio,9999,7,10,3,9999,3,0.7,5),3*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,-2,4,4,0.8))\' ',
'protocol_eprover_b1d72019af42f5b571a6c0b233a5b6d1de064075' => ' --definitional-cnf=24  --split-clauses=7 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.5,,02,500,1.0)\' -H\'(34*ConjectureLevDistanceWeight(ConstPrio,1,0,20,18,3,0,3,1.5,1),5*StaggeredWeight(PreferUnitGroundGoals,1))\' ',
'protocol_eprover_e60008599937a0dc787316fd87bf9ff4d65ffb48' => ' --definitional-cnf=24   --split-reuse-defs --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.5,,02,20000,1.0)\' -H\'(34*ConjectureLevDistanceWeight(PreferNonGoals,1,0,10,10,10,0,1,0.5,1),4*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,18,50,200,18,2,1,4))\' ',
'protocol_eprover_e6b386026570787d4ac06e541c4634c5e3f09cc5' => ' --definitional-cnf=24 --split-aggressive  --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.4,,02,100,1.0)\' -H\'(1*ConjectureRelativeTermWeight(PreferProcessed,1,1,0.1,50,100,100,3,1,1,2,0.7),2*RelevanceLevelWeight2(SimulateSOS,0,1,1,0,400,20,3,4,1.5,3,3),3*ConjectureGeneralSymbolWeight(PreferNonGoals,10,3,9999,300,100,20,400,1,3,3),5*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,200,100,10,0.5,1.5,1.5))\' ',
'protocol_eprover_6017f334107ca4679a9978dd19d7c76a8bd36e48' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4   --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,,1.4,,02,20000,1.0)\' -H\'(21*ConjectureLevDistanceWeight(ConstPrio,1,0,10,300,3,0,2,1.5,1),4*ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,0,1,1,2,3,5,2))\' ',
'protocol_eprover_e96ef4641ae500918cdd95fcfce21e29f2ac5eec' => ' --definitional-cnf=24 --split-aggressive    --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectCQPrecWNTNp --sine=\'GSinE(CountFormulas,,6.0,,03,100,1.0)\' -H\'(2*Defaultweight(DeferSOS),34*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,20,1.5,1.5,1.5),5*ConjectureGeneralSymbolWeight(ConstPrio,10,18,10,4,-2,7,0,3,0.2,2.5),8*ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,1,100,100,0,0.2,5,1))\' ',
'protocol_eprover_03d534503f753dd3be02bb3c547fa7a3e34e825e' => ' --definitional-cnf=24    --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*ConjectureGeneralSymbolWeight(ConstPrio,10,300,300,4,-2,4,50,3,0.2,2.5),1*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,200,2,4,3,0.8),1*FIFOWeight(PreferProcessed),4*RelevanceLevelWeight2(SimulateSOS,0,2,1,2,18,100,100,400,0.5,1.5,1))\' ',
'protocol_eprover_2e85aeff02a0bd3743f362014f6604d7fba54d74' => ' --definitional-cnf=24    --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG --sine=\'GSinE(CountFormulas,hypos,1.1,,02,500,1.0)\' -H\'(21*ConjectureGeneralSymbolWeight(PreferGroundGoals,18,4,9999,1,0,-2,50,0.1,5,3),3*Refinedweight(PreferUnitGroundGoals,50,100,0.8,1,0.1),4*ClauseWeightAge(DeferSOS,1,50,0.3,1),4*StaggeredWeight(DeferSOS,2))\' ',
'protocol_eprover_29f46a864b4eba32a7d0333eeab34cc2a3bfeeb2' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4 --split-reuse-defs --simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG --sine=\'GSinE(CountFormulas,hypos,1.1,,04,500,1.0)\' -H\'(2*ConjectureTermPrefixWeight(DeferSOS,1,3,0.1,10,0,1,3,0.3),3*Refinedweight(PreferGroundGoals,10,300,3,0.7,2),4*ConjectureLevDistanceWeight(SimulateSOS,1,0,3,18,1,0,2,1.5,1.5),8*ConjectureGeneralSymbolWeight(PreferGroundGoals,3,200,9999,5,0,0,7,0.3,3,1.5))\' ',
'protocol_eprover_1f734394cb6ce69b36c9826f6782d3567d6ecd6c' => ' --definitional-cnf=24 --split-aggressive  --split-reuse-defs --oriented-simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.1,,02,20000,1.0)\' -H\'(4*Clauseweight(PreferProcessed,0,1,1),4*ConjectureLevDistanceWeight(DeferSOS,1,0,300,400,2,0,3,0.7,9999.9))\' ',
'protocol_eprover_f8481b8ca6e1cbe7ac35251a2832c4c110836158' => ' --definitional-cnf=24  --split-clauses=4    --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,,1.2,,02,60,1.0)\' -H\'(1*PNRefinedweight(PreferUnitGroundGoals,0,1,-2,50,1,3,0.8),1*RelevanceLevelWeight2(SimulateSOS,2,0,1,0,-1,1,4,200,0.1,0.1,3),2*ConjectureGeneralSymbolWeight(ByCreationDate,300,400,18,-1,1,3,3,3,1.5,0.8),2*ConjectureGeneralSymbolWeight(PreferProcessed,50,20,4,7,4,400,50,1,0.1,0.1))\' ',
'protocol_eprover_334d43c175335e554899225728a5c2ebd420f86b' => ' --definitional-cnf=24      --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,200,2,2.5,4,1.5),10*ConjectureSymbolWeight(ConstPrio,200,300,7,200,5,0.3,1,0.5),2*SymbolTypeweight(SimulateSOS,7,400,50,400,9999.9,1,1.5),5*ConjectureSymbolWeight(ConstPrio,9999,50,-1,18,50,4,3,1))\' ',
'protocol_eprover_6c6e328223588bd61ac14315e52cd57432d78a40' => ' --definitional-cnf=24 --split-aggressive    --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.2,,04,20000,1.0)\' -H\'(21*PNRefinedweight(PreferUnitGroundGoals,5,20,2,18,9999.9,3,0.5),3*FIFOWeight(PreferProcessed),34*ConjectureGeneralSymbolWeight(PreferProcessed,100,300,50,4,-2,-2,50,3,0.2,4),4*ConjectureTermTfIdfWeight(ByCreationDate,0,2,1,10,2,5,1,4),8*ConjectureTermPrefixWeight(PreferGroundGoals,1,3,10,9999.9,0,0.7,3,5),8*FIFOWeight(DeferSOS))\' ',
'protocol_eprover_e9eb28a402764e1f99b41605245cd0a359f475fb' => ' --definitional-cnf=24  --split-clauses=7  --simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(2*ConjectureTermPrefixWeight(DeferSOS,1,3,1,100,0,4,0.3,4),21*ConjectureSymbolWeight(ConstPrio,200,300,7,10,10,0.3,0.3,0.7),3*Defaultweight(PreferNonGoals),4*ConjectureSymbolWeight(ConstPrio,9999,9999,-2,4,50,5,2,1.5))\' ',
'protocol_eprover_4692c23f3ccd5aecc2adbd7957ddb4b4144a02c8' => ' --definitional-cnf=24 --split-aggressive  --split-reuse-defs --oriented-simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*PNRefinedweight(PreferGroundGoals,7,-1,5,0,9999.9,9999.9,2.5),10*ConjectureSymbolWeight(ConstPrio,300,300,10,100,2,4,0.5,0.7),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,-2,4,4,0.8),2*ConjectureSymbolWeight(PreferUnitGroundGoals,50,-1,200,5,400,0.8,0.5,0.7))\' ',
'protocol_eprover_13918ce26d63c8fe682016bfda2032977bcbf85b' => ' --definitional-cnf=24 --split-aggressive  --split-reuse-defs --oriented-simul-paramod  --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*PNRefinedweight(DeferSOS,3,200,-2,18,5,1.5,2.5),10*ConjectureSymbolWeight(ConstPrio,9999,400,1,-2,2,4,0.7,0.3),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-2,1,4,1),2*ConjectureSymbolWeight(ConstPrio,9999,2,1,2,100,2.5,1,5))\' ',
'protocol_eprover_d060f57557112503de4e70311f17201fbe20b6a3' => ' --definitional-cnf=24    --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO6 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-1,1.5,5,1),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,100,100,100,1.5,1.5,1),1*FIFOWeight(PreferProcessed),2*Clauseweight(PreferUnitGroundGoals,7,9999,5),4*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,1.5,1.5,1.5))\' ',
'protocol_eprover_3dd3316ad6e39f95bf120b2757347c6970e0a532' => ' --definitional-cnf=24  --split-clauses=4  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG --sine=\'GSinE(CountFormulas,,1.1,,01,500,1.0)\' -H\'(1*ConjectureGeneralSymbolWeight(ConstPrio,2,300,10,4,-2,9999,5,1,3,3),34*ConjectureSymbolWeight(ConstPrio,300,200,7,0,400,0.1,4,2.5))\' ',
'protocol_eprover_b44ef8977635a59c8900801cfd301da75891626e' => ' --definitional-cnf=24  --split-clauses=4 --split-reuse-defs  --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.2,,04,20000,1.0)\' -H\'(34*ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,9999.9,3,5),34*OrientLMaxWeight(ConstPrio,2,1,0.7,5,2),34*RelevanceLevelWeight(ConstPrio,0,2,0,0,3,-1,-1,1,9999.9,2,0.5),4*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,1.5,1.5,1.5),8*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,20,1.5,1.5,1.5),8*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protocol_eprover_374255c1532cc4daa30b60038971be8183a2c553' => ' --definitional-cnf=24  --split-clauses=4    --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectComplexG --sine=\'GSinE(CountFormulas,hypos,1.4,,03,100,1.0)\' -H\'(13*Clauseweight(PreferUnitGroundGoals,7,9999,4),13*FIFOWeight(PreferProcessed),2*ConjectureLevDistanceWeight(PreferNonGoals,1,0,400,18,5,0,2.5,1.5,1.5),3*ConjectureTermPrefixWeight(PreferProcessed,1,3,100,9999.9,0,0.2,3,5),3*Defaultweight(DeferSOS),4*StaggeredWeight(ConstPrio,1.5))\' ',
'protocol_eprover_7e73d521eed2eff17dc17155adefb3ab5d9c1092' => ' --definitional-cnf=24    --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.4,,03,80,1.0)\' -H\'(1*Clauseweight(PreferProcessed,1,300,3),1*ConjectureRelativeTermWeight(ConstPrio,0,1,0.5,20,0,0,50,1,9999.9,4,2.5),2*StaggeredWeight(PreferUnitGroundGoals,1),3*RelevanceLevelWeight2(SimulateSOS,2,2,2,1,5,-2,-1,50,0.5,9999.9,9999.9),3*StaggeredWeight(PreferUnitGroundGoals,1))\' ',

# enigma
'ECprotokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 02, 100,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tKBO -H\'(6*EnigmaLgb(ConstPrio,malarea,0),4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\'  ' ,
'ECprotokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 5.0,, 02, 80,1.0)\' -Garity -WSelectNewComplexAHP --simul-paramod -tLPO4 -H\'(33*EnigmaLgb(ConstPrio,malarea,0),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ConstPrio,3,1,1),2*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ' ,
'ECprotokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 6.0,, 01, 80,1.0)\' -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(23*EnigmaLgb(ConstPrio,malarea,0),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ' ,
'ECprotokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Garity -WSelectComplexG --simul-paramod -tAuto -H\'(13*EnigmaLgb(ConstPrio,malarea,0),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\'  ', 
'ECprotokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 02, 100,1.0)\' --forward-context-sr -Garity -WSelectComplexG --simul-paramod --split-clauses=7 -tKBO -H\'(18*EnigmaLgb(ConstPrio,malarea,0),8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'ECprotokoll_atpstr_my_8fb389ef013a89e03c1aa87be52b2f151b1819cc' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.1,, 04, 80,1.0)\' -Garity -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-clauses=4 --split-reuse-defs -tAuto -H\'(15*EnigmaLgb(ConstPrio,malarea,0),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'ECprotokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.5,, 04, 100,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 -tLPO4 -H\'(24*EnigmaLgb(ConstPrio,malarea,0),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),4*Clauseweight(ConstPrio,3,1,1),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ', 
'ECprotokoll_atpstr_my_eba37f91665fc364eeb63558058658ee9a149d9a' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 02, 60,1.0)\' --forward-context-sr -Garity -WSelectNewComplexAHP --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(40*EnigmaLgb(ConstPrio,malarea,0),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),2*Clauseweight(ConstPrio,3,1,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),8*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'ECprotokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.5,, 2, 60,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --oriented-simul-paramod --split-aggressive --split-reuse-defs -tLPO4 -H\'(33*EnigmaLgb(ConstPrio,malarea,0),1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),8*Clauseweight(ConstPrio,3,1,1),2*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),10*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'ECprotokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 -Garity -WSelectComplexG --simul-paramod -tLPO4 -H\'(7*EnigmaLgb(ConstPrio,malarea,0),1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\' ',
'ECprotokoll_atpstr_my_fe548d15a6fc730fd350de634ad9d912ae198efd' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --simul-paramod --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred -H\'(11*EnigmaLgb(ConstPrio,malarea,0),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'ECprotocol_eprover_4a02c828a8cc55752123edbcc1ad40e453c11447' => ' --definitional-cnf=24   --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.4,,04,100,1.0)\' -H\'(10*EnigmaLgb(ConstPrio,malarea,0),1*Clauseweight(PreferUnitGroundGoals,4,9999,5),1*PNRefinedweight(PreferNonGoals,300,3,4,20,4,0.2,0.2),2*ConjectureLevDistanceWeight(ConstPrio,1,0,50,20,7,0,0.8,1.5,2),2*StaggeredWeight(PreferGroundGoals,1.5),4*ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,10,100,100,4,1.5,1))\' ',
'ECprotocol_eprover_f171197f65f27d1ba69648a20c844832c84a5dd7' => ' --definitional-cnf=24    --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO6 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(11*EnigmaLgb(ConstPrio,malarea,0),1*ConjectureSymbolWeight(ConstPrio,9999,5,10,50,50,4,3,0.5),1*ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,9999.9,3,5),1*FIFOWeight(PreferProcessed),3*ConjectureRelativeSymbolWeight(ConstPrio,0.7,100,100,100,100,2,1.5,1.5),5*Clauseweight(PreferUnitGroundGoals,7,9999,5))\' ',
'ECprotocol_eprover_29fa5c60d0ee03ec4f64b055553dc135fbe4ee3a' => ' --definitional-cnf=24  --split-clauses=7 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(13*EnigmaLgb(ConstPrio,malarea,0),1*StaggeredWeight(DeferSOS,1),2*ConjectureGeneralSymbolWeight(PreferNonGoals,5,100,300,4,-2,7,50,5,1,0.7),2*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,0,400,5,3,3,1),2*StaggeredWeight(DeferSOS,2),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.3,1.5,1.5))\' ',
'ECprotocol_eprover_773c90a94152ea2e8c9d3df9c4b1eb6152c40c03' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4 --split-reuse-defs --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.5,,,100,1.0)\' -H\'(9*EnigmaLgb(ConstPrio,malarea,0),1*Clauseweight(PreferGoals,20,9999,3),1*ConjectureTermPrefixWeight(ConstPrio,1,3,5,9999.9,2,5,5,5),1*FIFOWeight(PreferProcessed),2*ConjectureLevDistanceWeight(PreferNonGoals,1,0,20,300,4,0,2.5,0.8,3),4*ConjectureGeneralSymbolWeight(ConstPrio,4,10,200,3,-2,1,50,0.7,4,2))\' ',
'ECprotocol_eprover_2d86bd69119e7e9cc4417c0ee581499eaf828bb2' => ' --definitional-cnf=24  --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG --sine=\'GSinE(CountFormulas,,1.1,,02,500,1.0)\' -H\'(14*EnigmaLgb(ConstPrio,malarea,0),2*StaggeredWeight(DeferSOS,1.5),2*Uniqweight(PreferProcessed),4*ClauseWeightAge(ConstPrio,1,100,2.5,0.7),8*ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,3,4,9999,0,0,0,7,0.1,5,1.5))\' ',
'ECprotocol_eprover_230b6c199cce1dcf6700db59e75a93feb83d1bd9' => ' --definitional-cnf=24  --split-clauses=4  --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.1,,01,20000,1.0)\' -H\'(29*EnigmaLgb(ConstPrio,malarea,0),1*Clauseweight(PreferNonGoals,20,300,1.5),10*ConjectureGeneralSymbolWeight(PreferProcessed,100,9999,9999,4,-2,3,5,4,0.2,5),13*ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,100,400,-2,18,0,3,50,2.5,0.2,4),2*ConjectureRelativeSymbolWeight(PreferGroundGoals,2,7,-2,300,200,9999.9,2,2),3*FIFOWeight(PreferProcessed))\' ',
'ECprotocol_eprover_63dc1b1eb7d762c2f3686774d32795976f981b97' => ' --definitional-cnf=24    --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO6 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred  -H\'(11*EnigmaLgb(ConstPrio,malarea,0),1*ConjectureSymbolWeight(ConstPrio,9999,18,4,18,50,0.7,3,0.8),1*ConjectureTermPrefixWeight(ByCreationDate,1,3,1,9999.9,0,9999.9,3,5),1*FIFOWeight(PreferProcessed),3*ConjectureRelativeSymbolWeight(ConstPrio,0.7,100,100,100,100,2,1.5,1.5),5*Clauseweight(PreferProcessed,1,9999,5))\' ',
'ECprotocol_eprover_f6eb5f7f05126ea361481ae651a4823314e3d740' => ' --definitional-cnf=24  --split-clauses=4  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred --sine=\'GSinE(CountFormulas,hypos,1.5,,02,20000,1.0)\' -H\'(37*EnigmaLgb(ConstPrio,malarea,0),3*ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,50,18,7,20,1,1.5,4),34*ConjectureLevDistanceWeight(PreferNonGoals,1,0,10,10,10,0,1,0.5,3))\' '
);


my %gImproveStrats = (
"atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7" =>  "protokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7", 
"eprover_29fa5c60d0ee03ec4f64b055553dc135fbe4ee3a" =>	 "protocol_eprover_29fa5c60d0ee03ec4f64b055553dc135fbe4ee3a",
"atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113" =>  "protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113",
"eprover_773c90a94152ea2e8c9d3df9c4b1eb6152c40c03" =>	 "protocol_eprover_773c90a94152ea2e8c9d3df9c4b1eb6152c40c03",	 
"atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f" =>  "protokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f",
"eprover_f171197f65f27d1ba69648a20c844832c84a5dd7" =>    "protocol_eprover_f171197f65f27d1ba69648a20c844832c84a5dd7",    
);


foreach my $str (sort keys %gImproveStrats)
{
    my $prot = $gImproveStrats{$str};
    `mkdir $MBLISTRIN/$prot`;
}

sub RunBlistr
{
    my ($iter,$str) = @_;
    my $prot = $gImproveStrats{$str};
    `cd $MBLISTRIN/$prot; readlink -f * > ../../00$str.n$iter`;
    my $ttt1 = time();
    dprint "Running BliStr (hundreds of seconds) for $str with 00$str.n$iter\n";
    my @lines = `cd $MBLISTR; eprover_fast_tune.py strats/$str 00$str.n$iter | grep definitio`;
    my $ttt2 = time() - $ttt1;
    chomp(@lines);
    dprint "BliStr ran for $ttt2 s on $str, producing:\n", @lines, "###\n";
    return "  " . $lines[0] . "  ";
}

sub MkBlistrStrats
{
    my ($iter) = @_;
    my @strats = @gLTBstrats;
    foreach my $str (sort keys %gImproveStrats)
    {
	my $prot = RunBlistr($iter,$str);
	my $oldstr = $gImproveStrats{$str};
	my $newstr = $oldstr . "_iter" . $iter;
	$sdef{$newstr} = $prot;
	foreach my $i (0 .. $#gLTBstrats)
	{
	    if($gLTBstrats[$i]->[4] eq $oldstr)
	    {
		my @nrow=@{$gLTBstrats[$i]};
		$nrow[4]=$newstr;
		dprint "Changed $oldstr to $newstr\n";
#		dprint "Changed:\n$sdef{$oldstr}\nto\n$prot\n";
		$strats[$i]=\@nrow;	    
	    }
	}
    }
    return \@strats;
}


sub TrainEnigma
{
    my ($iter) = @_;
    my $ttt1 = time();
    dprint "Training Enigma\n";
    `mv $MENIGMATIC $MENIGMATIC.old_$iter`;
    `mkdir -p $MENIGMATIC`;
    `cp -a $MBLISTRIN/cnf $MENIGMATIC`;
    `cp -a $MBLISTROUT $MENIGMATIC`;
    `mv $MENIGMATIC/inputproofs $MENIGMATIC/out`;
    `cp $MBIN/mzr01 $MENIGMATIC/`;
    `cd $MENIGMATIC; ulimit -t 160000; $MBIN/make-enigma-model4 mzr01 malarea out cnf && killall make-enigma-model4`;
    my $ttt2 = time() - $ttt1;
    dprint "Enigma trained for $ttt2 s\n";
}


my $gparallel = 8; # the parallelization (nr of cores) - should be a parameter
my $greflimit = 800;  # how many hints we want from the ranker before we do slicing (just for speed up)
my $gdolsi = 0; # do the lsi training/predictions or not


AITP_Data::PrepareKNNTrain($gfilestem, 0, $gminrefs, $grefsyms, $greftrmstd, $greftrmnrm, \%gstdnr, \%gnrmnr);

my $time1 = time();
print "\nTime spent in data preparation:", $time1 - $gstarttime, "\n";

my ($glsiranking400,$glsioverlap400,$glsinames400); 
my ($glsiranking1000,$glsioverlap1000,$glsinames1000);

if($gdolsi > 0)
{
    ($glsiranking400,$glsioverlap400,$glsinames400) = AITP_Data::RunLSI($gfilestem,0,512,400,$grefsyms);
#    ($glsiranking1000,$glsioverlap1000,$glsinames1000) = AITP_Data::RunLSI($gfilestem,0,512,1000,$grefsyms);

    print "\nTime spent in LSI:", time() - $time1 , "\n";
}

print "\nTime spent in all preparation:", time() - $gstarttime, "\n";

# this is how we will run knn:
# ~/gr/MPTP2/MaLARea/script/knn.pl -w1 -L10 -M5 -t 001  02symst_notrivsyms  00c8k 40:20:10:5:4 1 0 


my $iter = 0;



# TODO: now just a stub, should be doing pseudo-minimization
sub Minimize
{
    my ($conj1,$nr1,$refs1,$strategy,$problem_limit,$ref2fla) = @_;
    return ($conj1,$nr1,$refs1); # if($nr1 < 4);

# write the file
# run atp
# extract the proof
}



# strat looks like:
# ["nrm",1,48,160,"protokoll_atpstr_my_a175515211bb22b22434eae9bbbfab623676a2ba"]
sub RunStrategy
{
    my ($strat,$conj,$tl,$solutionfile) = @_;

    my ($kind,$weighting,$k,$s,$estrat) = @$strat;

    #my @bla = ($kind,$weighting,$k,$s,$estrat);
    #foreach my $ff (0..$#bla) { die "Undefined $ff" unless(defined($bla[$ff])) }

    my $file = "$MTMP/$conj/$conj.prob.$kind.w$weighting.k$k.s$s";
    my $fname = "$conj.prob.$kind.w$weighting.k$k.s$s";
    
    unless(-r $file)
    {
	dprint "Cannot read problem file $file"; 
	`touch $file.out.$estrat`;
	dprint "Done:$strat\n";
	return;
    }

    #print "Command: ulimit -t $tl; $MBIN/eprover $sdef{$estrat} --tstp-format -R -s --cpu-limit=$tl $file 2>$file.err.$estrat | grep \"\\(User\\|SZS status\\)\" | tee $file.out.$estrat\n";

    die "Unknown strategy: $estrat\n$sdef::\n" unless(exists($sdef{$estrat}));

    dprint "Running ", join('.',@$strat), "for $tl s:\n";

    my $eparams = $sdef{$estrat};

#    dprint "E Params: $eparams .\n";
    
    my @lines = `ulimit -t $tl; $MBIN/eprover  $eparams --tstp-format -R --print-statistics -s --cpu-limit=$tl $file 2>$file.err.$estrat | grep "\\(User\\|SZS status\\)" | tee $file.out.$estrat`;

    foreach $_ (@lines)
    {
	if(m/.*SZS status[ :]*(Theorem)/)
	{
	    my $tl1 = 10+$tl;
	    my @plines = `ulimit -t $tl1; $MBIN/eprover $sdef{$estrat} --training-examples=3  --cpu-limit=$tl1 -p -s -R --print-statistics --tstp-format $file `;

	    my @status = grep { /.*SZS status[ :]*(Theorem)/ } @plines;
	    open(F,">$file.$estrat.out1"); 
	    if(scalar(@status)>0)
	    {
		mywarn "Proof found by slice ", join('.',@$strat), "\n"; 
		print F @plines;
		close(F);
		`cp $file.$estrat.out1 $MBLISTROUT`;
		`cp $file $MBLISTRIN/all`;
		`ulimit -t $tl1;  $MBIN/eprover --cnf --tstp-format $file | grep negated_conjecture > $MBLISTRIN/cnf/$fname.$estrat.out1`;
		`cp $file $MBLISTRIN/$estrat`;
		if(-e "$goutputdir/$solutionfile") { dprint "Done, proof exists already:$strat\n"; exit(0)}
		open(G,">$goutputdir/$solutionfile") or die " Cannot open solution file: $goutputdir/$solutionfile";
		dprint "% Getting lock on $goutputdir/$solutionfile\n";
		flock(G, 2); ## exclusive lock, will wait until all locks are removed
		dprint "% Getting lock on $goutputdir/$solutionfile\n";
		print G "# MaLARea strategy is $kind.w$weighting.k$k.s$s $estrat\n";
		print G @plines;
		flock(G, 8);
		dprint "% Unlocked $goutputdir/$solutionfile\n";
		close(G);
		dprint "Done:$strat\n";		
		exit(0);
	    }
	    else
	    {
		print F "# SZS status Theorem\n"; 
		close(F); # only return; do not exit, some other slice in this child could still assemble a proof
		return(0);
	    }
	}
    }
    dprint "Done:$strat\n";
    return;
}




# This is causes the child to exit
sub RunStrategiesSerial
{
    my ($strats,$conj,$problem_limit,$solutionfile) = @_;

    my $tl = max( 1, int( $problem_limit/(1+(scalar @$strats)) ));

    my $slack = $problem_limit - $tl*(1+(scalar @$strats));

    # if success, the child will exit in RunStrategy
    foreach my $strat (0 .. scalar(@$strats)-1)
    {
	my $tl1 = $tl;
	if($slack > 1)
	{
	    $slack--;
	    $tl1++;
	}
	RunStrategy($strats->[$strat],$conj,$tl1,$solutionfile);
    }    
    dprint "Done: RunStrategiesSerial\n";
    exit(0);
}


# run the strategies on the problem; return the status and the successful strategy (if any)
# 
sub RunStrategiesParallel
{
    my ($strats,$conj,$problem_limit,$parallel,$solutionfile) = @_;

    my $chunk_tlimit = $problem_limit; # no dividing, here we gain on parallelization

    my @stratchunks = (); # equal-sized chunks, make $parallel number of them 

    foreach my $i (0 .. $parallel-1) { $stratchunks[$i] = []; }

    # the strats go into the chunks according to their modulo $parallel
    foreach my $j (0 .. scalar(@$strats)-1)
    {
	my $mod = $j % $parallel;
	push( @{$stratchunks[$mod]}, $strats->[$j]);
    }

    my $status = szs_UNKNOWN ;

    # the parent ends the chunks by sending them $SIG{HUP}
    # the chunks speak to the parent by creating 

    my @childs = ();
    foreach my $chunk (@stratchunks)
    {

	my $pid = fork();
	if ($pid) 
	{
	    # parent
	    push(@childs, $pid);
	} 
	elsif ($pid == 0) 
	{
	    # child, if successful, creates the proof
	    $SIG{USR1} = \&childstopped;
	    RunStrategiesSerial($chunk,$conj,$chunk_tlimit,$solutionfile);
	    exit(0);
	} 
	else 
	{
	    die "couldn’t fork: $!\n";
	}
    }

    dprint "Parent:@childs\n";

    my $resultstrat = '';

    # while children exist, we update each second the list of
    # children, killing them all upon success
  LOOP1: while(scalar(@childs) > 0)
    {
	sleep 1;
	dprint "Parent:@childs\n";

	my @reaped = ();
	my %reapedh = ();
	while ((my $kid = waitpid(-1,WNOHANG)) > 0 )
	{
	    push(@reaped, $kid);
	    $reapedh{$kid} = ();
	}

	# If the prooffile is readable and unlocked, we wait
	# to get an exclusive lock and then kill all the children.
	# As soon as we get the lock, we know that the file is
	# written and no child will be able to change it
	# before we kill it. After they are all killed and reaped, we unlock.
	if(-e "$goutputdir/$solutionfile")
	{
	    dprint "% Solution exists\n";
	    open(MYFILE, "$goutputdir/$solutionfile") or die "Error in locking";
	    dprint "% Solution opened by master\n";
	    flock(MYFILE, 2); ## exclusive lock, will wait until all locks are removed
	    dprint "% Solution locked by master\n";
	    # kill 10, @childs; # SIGUSR1
	    kill 9, @childs; # SIGUSR1
	    dprint "% Signals sent by master\n";
	    dprint "Waiting:\n";
	    foreach (@childs) { waitpid($_, 0);}
	    dprint "Waited:\n";
	    my $strline = <MYFILE>;
	    if($strline =~ m/^# MaLARea strategy is\s+([^.]+)\.w(\d+)\.k(\d+)\.s(\d+)\s+(.*)/)
	    {
		$resultstrat = [$1,$2,$3,$4,$5];
	    }
	    else { mywarn "Bad strategy line in $goutputdir/$solutionfile: $strline\n"; }
	    flock(MYFILE, 8);
	    close(MYFILE);   # unlocks
	    $status = szs_THEOREM ;
	    @childs = ();
	    last LOOP1;
	}
	else
	{
	    my @newchilds = ();
	    foreach my $c (@childs)
	    {
		push(@newchilds,$c) unless(exists($reapedh{$c}));
	    }
	    @childs = @newchilds;
	}
    }

    # TODO: the strategy should write its name into the prooffile - needed for minimization
    return ($status,$resultstrat);
}


# use $strats to solve the problem with $problem_limit, getting the features from unknown flas first
sub Solve
{
    my ($strats,$prob,$problem_limit,$solutionfile,$forgetlimit,
	$iter,$ref2fla,$allallowed,$parallel) = @_;

    my $starttime = time();

    my @lines = `$MBIN/tptp4X -f tptp:short  -u machine -c $prob | $MBIN/CompressInsaneNames.pl `;
    return szs_GAVEUP if($#lines > $forgetlimit);  ## forget about this one
 
    my %getfeatures = (); # we need features from these
    my %allowed = ();  # these are the refs allowed for $prob
    my $conj = '';

    @allowed{@$allallowed} = ();
    foreach $_ (@lines)
    {

	if(m/^ *fof\( *([^, ]+) *, *([^, ]+) *,(.*)/)
	{
	    if(!exists($grefsyms->{$1}))
	    {
		$getfeatures{$1} = $_ ;
		mywarn "Features missing for $1\n";
	    }
	    if($2 eq 'conjecture')
	    {
		$conj = $1 
	    }
	    else { $allowed{$1} = (); }
	}
	elsif(m/^\s*include[(]\s*[']([^']+)[']\s*[)]\.\s*$/)
	{
	    my $i = $1;
	    my ($volume,$directories,$file) = File::Spec->splitpath( $i );
	    die "Include file was not known during training: $i" 
		unless(exists($gincludes->{$file}));
	    my @refs0 = keys %{$gincludes->{$file}};
	    @allowed{@refs0} = ();	    
	}
    }

    if($conj eq '') 
    { 
	mywarn "No conjecture in $prob, giving up\n";
	return szs_GAVEUP;
    }

    dprint "Nr of allowed refs for $conj: ", scalar(keys %allowed), "\n";


    if(-e "$MTMP/$conj") {`rm -rf $MTMP/$conj`;}
    `mkdir $MTMP/$conj`;

    AITP_Data::PrepareKNNTest("$MTMP/$conj/$conj.test", $iter, $conj, $grefsyms,
			      $greftrmstd, $greftrmnrm, \%gstdnr, \%gnrmnr);

    # copy the full problem
    `cp $prob $MTMP/$conj/$conj.prob.ful.w0.k0.s0`;

    my @manyknn = (8,16,32,48,64,128,256,512);

    # make the lsi files

    if($gdolsi > 0)
    {

	AITP_Data::MakeLSIPredictions($conj,$gfilestem,400,$iter,\%allowed,$ref2fla,\@manyknn,
				      $gminrefs,$glsiranking400,$glsioverlap400,$glsinames400);
#	AITP_Data::MakeLSIPredictions($conj,$gfilestem,1000,$iter,\%allowed,$ref2fla,\@manyknn,
#				      $gminrefs,$glsiranking1000,$glsioverlap1000,$glsinames1000);
    }

    my @childs = ();
    foreach my $weighting (1,2)
    {
	foreach my $kind ('nrm','std')
	{
	    my $pid = fork();
	    if ($pid) 
	    {
		# parent
		push(@childs, $pid);
	    } 
	    elsif ($pid == 0) 
	    {
		# child
		# AITP_Data::MakeKNNPredictions($conj,$gfilestem,$weighting,$greflimit,$kind,$iter,\%allowed,$ref2fla);

		AITP_Data::KNNBuiltInPredict($conj,$gfilestem,$weighting,$greflimit,$kind,$iter,\%allowed,$ref2fla,\@manyknn,$gminrefs,
					     $greftrmnrm,$greftrmstd,$gcn_wght_std1,$gcn_wght_std2,$gcn_wght_nrm1,$gcn_wght_nrm2);
		exit(0);
	    } 
	    else 
	    {
		die "couldn’t fork: $!\n";
	    }
	}
    }

    foreach (@childs) { waitpid($_, 0);}

    my $preparetime = (time() - $starttime);
    my $remaining_secs = $problem_limit - $preparetime;

    print "\nTime used for preparing $prob: ", $preparetime, "\n";

    # run on $MTMP/$conj/$conj.prob.$kind.w$weighting.k$k.s$s
    my ($status,$strategy) = RunStrategiesParallel($strats,$conj,$remaining_secs,$parallel,$solutionfile);

    print "\nTime used for $prob: ", time() - $starttime, "\n";
    return ($status,$strategy);
}

# The problems solved so far - not to be attempted again
my %gsolved = ();
my %gunsolved = ();
my $gproblem_limit = 4;

foreach my $batch (@$gbatches)
{
    my ($execution_order, $output_required, $problem_limit, $overall_limit, 
	$include_files1, $ltbprobnames1, $ltbprobsolutions1) 
	= @$batch;

    my %include_files = %$include_files1;
    my @ltbprobnames = @$ltbprobnames1; 
    my %ltbprobsolutions = %$ltbprobsolutions1;

    $problem_limit = $gproblem_limit;

    # formulas in the batch inclusion files are allowed in each problem
    my %allallowedh = ();
    foreach my $i (sort keys %$include_files1)
    {
	my ($volume,$directories,$file) = File::Spec->splitpath( $i );
#	die "Include file was not known during training: $i" 
#	    unless(exists($gincludes->{$file}));
#	my @refs0 = keys %{$gincludes->{$file}};
	my @refs0 = ();
	@allallowedh{@refs0} = ();	    
    }


    my @allallowed = sort keys %allallowedh;

    dprint "Nr of refs allowed everywhere: $#allallowed \n";

    my $strats = \@gLTBstrats;
    my $gblistr_strats;
    my $niter = 0;
    while($niter < 100)
    {
	$niter++;

	# if(1 == ($niter % 2)) {$problem_limit = 4; $strats = \@gLTBstrats;}
	# elsif(0 == ($niter % 2)) {$problem_limit = 40; $strats = \@gLTBstratsIter2;}

	if(1 == ($niter % 5)) {$problem_limit = 4; $strats = \@gLTBstrats;}
	elsif(2 == ($niter % 5)) {$problem_limit = 20; $strats = \@gLTBstratsIter2Enigma; TrainEnigma($niter);}
#$problem_limit = 40; $strats = \@gLTBstratsIter2;}
	elsif(3 == ($niter % 5)) {$problem_limit = 4; $strats = \@gLTBstratsIter2Enigma; TrainEnigma($niter);}
#$strats = \@gLTBstrats;} # $gblistr_strats = MkBlistrStrats($niter); $strats = $gblistr_strats}
	elsif(4 == ($niter % 5)) {$problem_limit = 20; $strats = \@gLTBstratsIter2Enigma; TrainEnigma($niter);}
#$strats = \@gLTBstratsIter2;} # $gblistr_strats;}
	elsif(0 == ($niter % 5)) {$problem_limit = 40; $strats = \@gLTBstrats;}
# {if(0 == ($niter % 10)) {$problem_limit = 160; $strats = $gblistr_strats} else {$problem_limit = 80; $strats = \@gLTBstrats;}}


	# if($niter == 2) {$problem_limit = 40; $strats = \@gLTBstratsIter2;}
	# elsif($niter == 3) {$problem_limit = 4; $strats = \@gLTBstrats;}
	my $remaining_secs = $overall_limit - (time() - $gstarttime);
    	print "\n% Batch Iteration $niter\n% Time remaining: $remaining_secs\n";
	print "% Problems solved already: ", join(", ",sort keys %gsolved), "\n";
    foreach my $prob (@ltbprobnames)
    {
	if(!exists($gsolved{$prob}))
	{
	print "\n% SZS status Started for $prob\n";
	my ($status,$strategy) = Solve($strats,$prob,$problem_limit,$ltbprobsolutions{$prob},$gforgetlimit,
				       $iter,$gref2fla,\@allallowed,$gparallel);

	print "\n% SZS status $status for $prob\n";
	print "\n% SZS status Ended for $prob\n";
	
	# update if possible
	if($status eq szs_THEOREM)
	{
	    $gsolved{$prob} = 1;
	    my ($conj1,$nr1,$refs1) = AITP_Data::GetProofSummary("$goutputdir/" . $ltbprobsolutions{$prob});
	    if($nr1 != 0)
	    {
		my ($conj2,$nr2,$refs2) = Minimize($conj1,$nr1,$refs1,$strategy,$problem_limit,$gref2fla);

		($conj1,$nr1,$refs1) = ($conj2,$nr2,$refs2) if($nr2 != 0);

		$gminrefs->{$conj1} = $refs1;
		$iter++;
		AITP_Data::PrepareKNNTrain($gfilestem, $iter, $gminrefs, $grefsyms, 
					   $greftrmstd, $greftrmnrm, \%gstdnr, \%gnrmnr);
	    }
	}

	$remaining_secs = $overall_limit - (time() - $gstarttime);
	print "\nTime remaining: $remaining_secs\n";
	}
    }
    }
    $gstarttime = time();
}

exit(0);
